# Parser Screens Editor

### Description

A single-page web app to help edit screens in `parsers.json` files.

### Usage

To open the app, double click the `index.html` and it will open in a web browser.

To start editing `parsers.json` file either drag and drop it into the dashed area or click on the dashed area to open file chooser dialog.

Start editing entry labels and values by simply clicking on the text. Once finished, download the updated `parsers.json` by clicking the Download button at the top.
